==> trade-center-biz-0.2.0-20161107.064854-2-sources.jar: cn/com/duiba/order/center/biz/remoteservice/RemoteTransactionBoServiceImpl.java <==
package cn.com.duiba.order.center.biz.remoteservice;

import cn.com.duiba.order.center.api.dto.OrdersDto;
import cn.com.duiba.order.center.api.dto.SupplierOrderDto;
import cn.com.duiba.order.center.api.remoteservice.RemoteTransactionBoService;
import cn.com.duiba.order.center.biz.bo.TransactionBo;
import cn.com.duiba.service.exception.BusinessException;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Created by yansen on 16/10/9.
 */
@Service
public class RemoteTransactionBoServiceImpl implements RemoteTransactionBoService {

    @Autowired
    private TransactionBo transactionBo;

    @Override
    public DubboResult<Boolean> doMakeConsumeSuccess(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doMakeConsumeSuccess(orderId, consumerId));
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doMakeConsumeFail(Long orderId, Long consumerId, Integer failType, String error4consumer, String error4developer, String error4admin) {
        try {
            return DubboResult.successResult(transactionBo.doMakeConsumeFail(orderId, consumerId, failType, error4consumer, error4developer, error4admin));
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doAmbPaySuccess(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doAmbPaySuccess(orderId, consumerId));
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doAuditReject(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doAuditReject(orderId, consumerId));
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doMakeSuccess(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doMakeSuccess(orderId, consumerId));
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doMakeFail(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doMakeFail(orderId, consumerId));
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doUpdateAllowInputUsed(Long orderId, Long consumerId, SupplierOrderDto supplierOrder, String bizParams, String brief) {
        try {
            return DubboResult.successResult(transactionBo.doUpdateAllowInputUsed(orderId, consumerId, supplierOrder, bizParams, brief));
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Void> createPayBackRecordAtMakeFail(OrdersDto orders) {
        try {
            transactionBo.createPayBackRecordAtMakeFail(orders);
            return DubboResult.successResult(null);
        } catch (BusinessException e) {
            return DubboResult.failResult(e.getMessage());
        }
    }
}

==> trade-center-biz-0.5.3-20161220.020755-1-sources.jar: cn/com/duiba/order/center/biz/remoteservice/RemoteTransactionBoServiceImpl.java <==
package cn.com.duiba.order.center.biz.remoteservice;

import cn.com.duiba.boot.ext.autoconfigure.logger.DuiBaLogger;
import cn.com.duiba.boot.ext.autoconfigure.logger.DuiBaLoggerFactory;
import cn.com.duiba.order.center.api.dto.OrdersDto;
import cn.com.duiba.order.center.api.dto.SupplierOrderDto;
import cn.com.duiba.order.center.api.remoteservice.RemoteTransactionBoService;
import cn.com.duiba.order.center.biz.bo.TransactionBo;
import cn.com.duiba.service.exception.BusinessException;
import cn.com.duiba.wolf.dubbo.DubboResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Created by yansen on 16/10/9.
 */
@Service
public class RemoteTransactionBoServiceImpl implements RemoteTransactionBoService {
	
	private static DuiBaLogger log = DuiBaLoggerFactory.getLogger(RemoteTransactionBoServiceImpl.class);

    @Autowired
    private TransactionBo transactionBo;

    @Override
    public DubboResult<Boolean> doMakeConsumeSuccess(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doMakeConsumeSuccess(orderId, consumerId));
        } catch (BusinessException e) {
        	log.error("doMakeConsumeSuccess",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doMakeConsumeFail(Long orderId, Long consumerId, Integer failType, String error4consumer, String error4developer, String error4admin) {
        try {
            return DubboResult.successResult(transactionBo.doMakeConsumeFail(orderId, consumerId, failType, error4consumer, error4developer, error4admin));
        } catch (BusinessException e) {
        	log.error("doMakeConsumeFail",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doAmbPaySuccess(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doAmbPaySuccess(orderId, consumerId));
        } catch (BusinessException e) {
        	log.error("doAmbPaySuccess",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doAuditReject(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doAuditReject(orderId, consumerId));
        } catch (BusinessException e) {
        	log.error("doAuditReject",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doMakeSuccess(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doMakeSuccess(orderId, consumerId));
        } catch (BusinessException e) {
        	log.error("doMakeSuccess",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doMakeFail(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doMakeFail(orderId, consumerId));
        } catch (BusinessException e) {
        	log.error("doMakeFail",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doUpdateAllowInputUsed(Long orderId, Long consumerId, SupplierOrderDto supplierOrder, String bizParams, String brief) {
        try {
            return DubboResult.successResult(transactionBo.doUpdateAllowInputUsed(orderId, consumerId, supplierOrder, bizParams, brief));
        } catch (BusinessException e) {
        	log.error("doUpdateAllowInputUsed",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Void> createPayBackRecordAtMakeFail(OrdersDto orders) {
        try {
            transactionBo.createPayBackRecordAtMakeFail(orders);
            return DubboResult.successResult(null);
        } catch (BusinessException e) {
        	log.error("createPayBackRecordAtMakeFail",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doUpdateAllowInputUsed4Object(Long orderId, Long consumerId, SupplierOrderDto supplierOrder, String bizParams){
        try {
            return DubboResult.successResult(transactionBo.doUpdateAllowInputUsed4Object(orderId, consumerId, supplierOrder, bizParams));
        }catch (BusinessException e) {
            log.error("doUpdateAllowInputUsed4Object",e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> doAmbStatusAfterSend(Long orderId, Long consumerId) {
        try {
            return DubboResult.successResult(transactionBo.doAmbStatusAfterSend(orderId, consumerId));
        } catch (BusinessException e) {
            log.error("doAmbStatusAfterSend", e);
            return DubboResult.failResult(e.getMessage());
        }
    }
}
